all_non_interactions: Select non-interaction constructs from a measurement model

all_non_interactionsR Documentation

Select non-interaction constructs from a measurement model

Description

Filters out interaction constructs from a measurement model list, returning only the constructs specified via 'composite()', 'reflective()', or higher-order construct constructors.

Usage

all_non_interactions(measurement_model)

Arguments

measurement_model

A 'measurement_model' list (e.g., the output of 'constructs()').

Value

A filtered list of construct specifications with all interaction constructs removed.


seminr documentation built on May 25, 2026, 9:06 a.m.