construct_names: Get construct names from a model or model component

View source: R/helpers-smMatrix.R

construct_namesR Documentation

Get construct names from a model or model component

Description

S3 generic that returns the construct names found in a model, measurement model, structural model, or related object. Methods dispatch on the class of 'x'.

Usage

construct_names(x, ...)

Arguments

x

A 'seminr_model', 'measurement_model', 'structural_model', 'mmMatrix', or related object.

...

Additional arguments passed to methods.

Value

A character vector of construct names.


seminr documentation built on May 25, 2026, 9:06 a.m.