edge_template_minimal: A minimal template for labeling bootstrapped edges that only...

View source: R/theme.R

edge_template_minimalR Documentation

A minimal template for labeling bootstrapped edges that only shows the bootstrapped mean value

Description

A minimal template for labeling bootstrapped edges that only shows the bootstrapped mean value

Usage

edge_template_minimal()

Value

The template string


seminr documentation built on May 25, 2026, 9:06 a.m.