Learn R Programming

seminr (version 1.0.2)

estimate_pls: seminr estimate_pls() function

Description

The seminr package provides a natural syntax for researchers to describe PLS structural equation models.

Usage

estimate_pls(data, measurement_model, structural_model,
             inner_weights = path_weighting)

Arguments

data

A dataframe containing the indicator measurement data.

measurement_model

A source-to-target matrix representing the outer/measurement model, generated by constructs.

structural_model

A source-to-target matrix representing the inner/structural model, generated by relationships.

inner_weights

A parameter declaring which inner weighting scheme should be used path_weighting is default, alternately path_factorial can be used.

See Also

relationships constructs paths interaction_term bootstrap_model

Examples

Run this code
# NOT RUN {
mobi <- mobi

#seminr syntax for creating measurement model
mobi_mm <- constructs(
             reflective("Image",        multi_items("IMAG", 1:5)),
             reflective("Expectation",  multi_items("CUEX", 1:3)),
             reflective("Quality",      multi_items("PERQ", 1:7)),
             reflective("Value",        multi_items("PERV", 1:2)),
             reflective("Satisfaction", multi_items("CUSA", 1:3)),
             reflective("Complaints",   single_item("CUSCO")),
             reflective("Loyalty",      multi_items("CUSL", 1:3))
           )
#seminr syntax for creating structural model
mobi_sm <- relationships(
  paths(from = "Image",        to = c("Expectation", "Satisfaction", "Loyalty")),
  paths(from = "Expectation",  to = c("Quality", "Value", "Satisfaction")),
  paths(from = "Quality",      to = c("Value", "Satisfaction")),
  paths(from = "Value",        to = c("Satisfaction")),
  paths(from = "Satisfaction", to = c("Complaints", "Loyalty")),
  paths(from = "Complaints",   to = "Loyalty")
)

mobi_pls <- estimate_pls(data = mobi,
                         measurement_model = mobi_mm,
                         structural_model = mobi_sm)

summary(mobi_pls)
plot_scores(mobi_pls)
# }

Run the code above in your browser using DataLab