extract_mm_coding: extracts the constructs and their types from the model

View source: R/plot_dot.R

extract_mm_codingR Documentation

extracts the constructs and their types from the model

Description

extracts the constructs and their types from the model

Usage

extract_mm_coding(model)

Arguments

model

the model to use


seminr documentation built on May 25, 2026, 9:06 a.m.