Learn R Programming

seminr (version 1.0.2)

higher_composite: higher_composite

Description

higher_composite creates a higher order construct from first order constructs using the two-stage method (Becker et al., 2012).

Usage

higher_composite(construct_name, dimensions, method, weights)

Arguments

construct_name

of second order construct

dimensions

the first order constructs

method

is the estimation method, default is two_stage

weights

is the relationship between the second order construct and first order constructs. This can be specified as correlation_weights or mode_A for correlation weights (Mode A) or as regression_weights or mode_B for regression weights (Mode B). Default is correlation weights.

Details

This function conveniently maps first order constructs onto second order constructs using construct names.

See Also

See constructs, reflective

Examples

Run this code
# NOT RUN {
  mobi_mm <- constructs(
    composite("Image",        multi_items("IMAG", 1:5), weights = correlation_weights),
    composite("Expectation",  multi_items("CUEX", 1:3), weights = mode_A),
    higher_composite("Quality",  c("Image","Expectation"), method = two_stage),
    composite("Value",        multi_items("PERV", 1:2), weights = mode_B)
  )
# }

Run the code above in your browser using DataLab