View source: R/specify_interactions.R
| quadratic_term | R Documentation |
quadratic_term is a convenience wrapper around interaction_term
for creating a quadratic effect of a single construct (i.e., X squared).
It is equivalent to calling interaction_term(iv = construct, moderator = construct, ...).
quadratic_term(iv, method, weights)
iv |
The construct to square. |
method |
The method to generate the quadratic term with a default of
|
weights |
The weighting mode for quadratic items in a PLS model (only)
with default of |
The resulting construct in the structural model is named "X*X" where
X is the construct name. Reference it accordingly in paths().
An un-evaluated function (promise) for generating a quadratic term,
identical to what interaction_term(iv, iv, method, weights) returns.
data(mobi)
mobi_mm <- constructs(
composite("Image", multi_items("IMAG", 1:5)),
composite("Satisfaction", multi_items("CUSA", 1:3)),
quadratic_term(iv = "Image", method = two_stage)
)
mobi_sm <- relationships(
paths(to = "Satisfaction",
from = c("Image", "Image*Image"))
)
mobi_pls <- estimate_pls(mobi, mobi_mm, mobi_sm)
summary(mobi_pls)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.