Learn R Programming

seminr (version 1.0.2)

two_stage: two_stage creates an interaction measurement item by the two-stage approach.

Description

This function automatically generates an interaction measurement item for a PLS SEM using the two-stage approach.

Usage

# two stage approach as per Henseler & Chin (2010):
 two_stage(iv, moderator, weights)

Arguments

iv

The independent variable that is subject to moderation.

moderator

The moderator variable.

weights

is the relationship between the items and the interaction terms. This can be specified as correlation_weights or mode_A for correlation weights (Mode A) or as regression_weights or mode_B for regression weights (Mode B). Default is correlation weights.

References

Henseler & Chin (2010), A comparison of approaches for the analysis of interaction effects between latent variables using partial least squares path modeling. Structural Equation Modeling, 17(1),82-109.

Examples

Run this code
# NOT RUN {
data(mobi)

# seminr syntax for creating measurement model
mobi_mm <- constructs(
  composite("Image",        multi_items("IMAG", 1:5)),
  composite("Expectation",  multi_items("CUEX", 1:3)),
  composite("Value",        multi_items("PERV", 1:2)),
  composite("Satisfaction", multi_items("CUSA", 1:3)),
  interaction_term(iv = "Image", moderator = "Expectation", method = two_stage)
)

#  structural model: note that name of the interactions construct should be
#  the names of its two main constructs joined by a '*' in between.
mobi_sm <- relationships(
  paths(to = "Satisfaction",
        from = c("Image", "Expectation", "Value",
                 "Image*Expectation"))
)

mobi_pls <- estimate_pls(mobi, mobi_mm, mobi_sm)
summary(mobi_pls)

# }

Run the code above in your browser using DataLab