| all_non_interactions | R Documentation |
Filters out interaction constructs from a measurement model list, returning only the constructs specified via 'composite()', 'reflective()', or higher-order construct constructors.
all_non_interactions(measurement_model)
measurement_model |
A 'measurement_model' list (e.g., the output of 'constructs()'). |
A filtered list of construct specifications with all interaction constructs removed.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.