View source: R/helpers-smMatrix.R
| construct_names | R Documentation |
S3 generic that returns the construct names found in a model, measurement model, structural model, or related object. Methods dispatch on the class of 'x'.
construct_names(x, ...)
x |
A 'seminr_model', 'measurement_model', 'structural_model', 'mmMatrix', or related object. |
... |
Additional arguments passed to methods. |
A character vector of construct names.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.